@@ -1,10 +1,13 @@
 from __future__ import annotations
 
+import sys
+from itertools import chain
 from typing import TYPE_CHECKING, Sequence
 
 from tox.config.main import Config
 from tox.journal import Journal
 from tox.plugin import impl
+from tox.plugin.manager import MANAGER
 
 from .env_select import EnvSelector
 
@@ -17,7 +20,13 @@ class State:
     """Runtime state holder."""
 
     def __init__(self, options: Options, args: Sequence[str]) -> None:
-        self.conf = Config.make(options.parsed, options.pos_args, options.source)
+        extended_envs = chain.from_iterable(MANAGER.tox_extend_envs())
+        self.conf = Config.make(options.parsed, options.pos_args, options.source, extended_envs)
+        self.conf.core.add_constant(
+            keys=["on_platform"],
+            desc="platform we are running on",
+            value=sys.platform,
+        )
         self._options = options
         self.args = args
         self._journal: Journal = Journal(getattr(options.parsed, "result_json", None) is not None)
@@ -33,7 +42,7 @@ class State:
 
 @impl
 def tox_add_option(parser: ToxParser) -> None:
-    from tox.tox_env.register import REGISTER
+    from tox.tox_env.register import REGISTER  # noqa: PLC0415
 
     parser.add_argument(
         "--runner",
