@@ -401,7 +401,7 @@ def test_requirements_file_missing(tmp_path: Path) -> None:
     requirements_file = tmp_path / "req.txt"
     requirements_file.write_text("-r one.txt")
     req_file = RequirementsFile(requirements_file, constraint=False)
-    with pytest.raises(ValueError, match="No such file or directory: .*one.txt"):
+    with pytest.raises(ValueError, match=r"No such file or directory: .*one.txt"):
         assert req_file.options
 
 
@@ -423,7 +423,7 @@ def test_req_path_with_space_escape(tmp_path: Path) -> None:
     dep_requirements_file = tmp_path / "a b"
     dep_requirements_file.write_text("c")
     path = f"-r {dep_requirements_file!s}"
-    path = f'{path[:-len("a b")]}a\\ b'
+    path = f"{path[: -len('a b')]}a\\ b"
 
     requirements_file = tmp_path / "req.txt"
     requirements_file.write_text(path)
